@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <bonobo/bonobo-i18n.h>
+#include <config.h>
 #include <gtk/gtkbbox.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkenums.h>
@@ -31,6 +31,7 @@
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-list.h>
 #include <libgnomedb/gnome-db-util.h>
+#include <bonobo/bonobo-i18n.h>
 
 #define PARENT_TYPE GTK_TYPE_VBOX
 
@@ -160,7 +161,7 @@ create_navigator (GnomeDbForm *form)
 				  GTK_FILL, GTK_FILL, 2, 2);
 
 		switch (gda_field_attributes_get_gdatype (fa)) {
-		case GDA_TYPE_BOOLEAN :
+		case GDA_VALUE_TYPE_BOOLEAN :
 			entry = gnome_db_new_check_button_widget (NULL);
 			gtk_widget_set_sensitive (entry, FALSE);
 			break;
