@@ -110,7 +110,14 @@ sort_values (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpoint
 		/* data types don't match, so use strings to sort */
 		stra = gda_value_stringify ((GdaValue *) valuea);
 		strb = gda_value_stringify ((GdaValue *) valueb);
-		retval = strcmp (stra, strb);
+		if (!stra && !strb)
+			retval = 0;
+		else if (!stra)
+			retval = 1;
+		else if (!strb)
+			retval = -1;
+		else
+			retval = strcmp (stra, strb);
 
 		g_free (stra);
 		g_free (strb);
@@ -256,7 +263,6 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 				toggle_value_set_func,
 				GINT_TO_POINTER (i),
 				NULL);
-			gda_field_attributes_free (attrs);
 		}
 		else {
 			renderer = gtk_cell_renderer_text_new ();
@@ -282,6 +288,8 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 						 i, sort_values,
 						 GINT_TO_POINTER (i),
 						 NULL);
+		if (attrs)
+			gda_field_attributes_free (attrs);
 	}
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (tree_model),
